@@ -304,7 +304,7 @@ class mtse:
         torch.backends.cudnn.enabled=False
         best_val_loss = float('inf'); total_time = 0.; train_losses, val_losses = [], []    
         save_strategy = predict_strategy if predict_strategy == 'best' else save_strategy
-        argmax = True if lossf == 'cross_entropy' else argmax
+        #argmax = True if lossf == 'cross_entropy' else argmax
         
         lf = {'mae': nn.L1Loss(), 'mape': mape, 'rmse': rmse, 'rmspe': rmspe, 'mse': nn.MSELoss(), 'accuracy': acc, 'cross_entropy': nn.CrossEntropyLoss()}
         try:
